Documentation
¶
Index ¶
- Constants
- type Server
- func (srv *Server) GetDbDsnA() (dsn string)
- func (srv *Server) GetDbDsnB() (dsn string)
- func (srv *Server) GetListenDsn() (dsn string)
- func (srv *Server) GetStopChannel() *chan bool
- func (srv *Server) GetWorkMode() (modeId byte)
- func (srv *Server) Start() (cerr *ce.CommonError)
- func (srv *Server) Stop() (cerr *ce.CommonError)
Constants ¶
const ( DbClientPoolTakeRetryDelayMs = 100 // DbClientPoolTakeAttemptsCountLimit is the limit for number of attempts // to try to get a client from the pool. // (100ms * 10) * 60 => 1 Minute. DbClientPoolTakeAttemptsCountLimit = 10 * 60 )
const (
ServerName = "SFHS"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
func (*Server) GetListenDsn ¶
func (*Server) GetStopChannel ¶
func (*Server) GetWorkMode ¶ added in v0.14.0
func (*Server) Start ¶
func (srv *Server) Start() (cerr *ce.CommonError)
func (*Server) Stop ¶
func (srv *Server) Stop() (cerr *ce.CommonError)
Click to show internal directories.
Click to hide internal directories.